# -*- coding: utf-8 -*-
#
# Do NOT edit this system file by hand -- use git.
# See "URL to git source" below.
#
# Author:        $Id: Thomas R. Stevenson <aa0026@wayne.edu> $
#
# Last Changed:  $Date: Thu Jan 26 11:02:02 2023 -0500 $
#
# URL to git source: $URL: git@git.wayne.edu:ECS_Projects/ECSpylibs.git $
#
# ECSpylibs

-rw-r--r--. 1 tom tom 2568 Feb  2 13:57 src/ecspylibs/buildfunctionlist.py
-rw-r--r--. 1 tom tom 8390 Feb  2 13:57 src/ecspylibs/checkservice.py
-rw-r--r--. 1 tom tom 3090 Feb  2 13:57 src/ecspylibs/cleanuptempdirs.py
-rw-r--r--. 1 tom tom  465 Jan 26 11:05 src/ecspylibs/__init__.py
-rw-r--r--. 1 tom tom 3678 Feb  2 13:57 src/ecspylibs/initsetup.py
-rw-r--r--. 1 tom tom 1676 Feb  8 12:50 src/ecspylibs/parallel.py
-rw-r--r--. 1 tom tom 4965 Feb  2 13:57 src/ecspylibs/parseemail.py
-rw-r--r--. 1 tom tom 3644 Feb  2 13:57 src/ecspylibs/parsexml.py
-rw-r--r--. 1 tom tom 3650 Feb  2 13:57 src/ecspylibs/password.py
-rw-r--r--. 1 tom tom 1879 Feb  2 13:57 src/ecspylibs/reapchildren.py
-rw-r--r--. 1 tom tom 2993 Feb  2 13:57 src/ecspylibs/sendemail.py

The GIT Home can be found [Here][ECSPYLIBS].
The README file can be found [Here][README].
The LICENSE file can be found [Here][LICENSE].
The ChangeLog file can be found [Here][CHANGELOG].
The pyproject.toml file can be found [Here][PYPROJECT].
My contact information can be found [Here][About Me].

[ECSPYLIBS]: https://git.wayne.edu/ECS_Projects/ECSpylibs
[README]: https://git.wayne.edu/ECS_Projects/ECSpylibs/-/blob/master/README.md
[LICENSE]: https://git.wayne.edu/ECS_Projects/ECSpylibs/-/blob/master/LICENSE.txt
[CHANGELOG]: https://git.wayne.edu/ECS_Projects/ECSpylibs/-/blob/master/ChangeLog
[PYPROJECT]: https://git.wayne.edu/ECS_Projects/ECSpylibs/-/blob/master/pyproject.toml
[About Me]: https://About.Me/Thomas.R.Stevenson
